aboutsummaryrefslogtreecommitdiffstats
path: root/tools/xmlGenerator/hostDomainGenerator.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/xmlGenerator/hostDomainGenerator.sh')
-rwxr-xr-xtools/xmlGenerator/hostDomainGenerator.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/tools/xmlGenerator/hostDomainGenerator.sh b/tools/xmlGenerator/hostDomainGenerator.sh
index 9bf8606..65b8189 100755
--- a/tools/xmlGenerator/hostDomainGenerator.sh
+++ b/tools/xmlGenerator/hostDomainGenerator.sh
@@ -32,13 +32,13 @@ set -ueo pipefail
# Leave standard output unmodified
exec 4>&1
-# If the verbose long option is provided, output info log lines prefixed on stderr.
-if test "$1" == --verbose
+# If the nonverbose long option is provided, do not output info log lines prefixed on stderr.
+if test "$1" == --nonverbose
then
shift
- exec 1> >(sed 's/^/Info: /' >&2)
-else
exec 1>/dev/null
+else
+ exec 1> >(sed 's/^/Info: /' >&2)
fi
# Prefix all warning and error log lines and redirect them to stderr
exec 5> >(sed 's/^/Warning: /' >&2)